@@ -302,13 +302,13 @@ patRegW <- function(sampleList,
       seed[as.numeric(xy[1]),as.numeric(xy[2]),1,1] <- 2
     }
 
-    print("Choose at leat one point to identify background. Click outside image area to stop.")
+    print("Choose at least one point to identify background. Click outside image area to stop.")
 
     while(1){
 
       xy <- locator(n=1)
 
-      if(as.numeric(xy)[1] > dim(im)[1] || as.numeric(xy)[1] < 0 || as.numeric(xy)[2] > dim(im)[2] || as.numeric(xy)[2] < 0){
+      if(any(c(as.numeric(xy)[1] > dim(im)[1], as.numeric(xy)[1] < 0, as.numeric(xy)[2] > dim(im)[2], as.numeric(xy)[2] < 0))){
         break
       }
 
